/**
 * @agentuity/drizzle - DEPRECATED
 *
 * Use drizzle-orm/node-postgres with pg directly against your DATABASE_URL.
 * This package is no longer recommended for new projects.
 *
 * ~~Drizzle ORM integration with resilient PostgreSQL connections~~
 *
 * This package provided a seamless integration between Drizzle ORM and
 * @agentuity/postgres, combining type-safe database queries with automatic
 * reconnection capabilities.
 *
 * @example
 * ```typescript
 * import { createPostgresDrizzle, pgTable, text, serial } from '@agentuity/drizzle';
 *
 * // Define your schema
 * const users = pgTable('users', {
 *   id: serial('id').primaryKey(),
 *   name: text('name').notNull(),
 *   email: text('email').notNull().unique(),
 * });
 *
 * // Create the database instance
 * const { db, close } = createPostgresDrizzle({
 *   schema: { users },
 * });
 *
 * // Execute type-safe queries
 * const allUsers = await db.select().from(users);
 *
 * // Clean up when done
 * await close();
 * ```
 *
 * @packageDocumentation
 */
export { createPostgresDrizzle, drizzle } from './postgres.ts';
export type { PostgresDrizzleConfig, PostgresDrizzle, PostgresDrizzlePg } from './types.ts';
export { postgres, PostgresClient, type CallablePostgresClient, type PostgresConfig, type ReconnectConfig, type ConnectionStats, type TLSConfig, type TransactionOptions, type ReserveOptions, } from '@agentuity/postgres';
export { sql, eq, and, or, not, desc, asc, gt, gte, lt, lte, ne, isNull, isNotNull, inArray, notInArray, between, like, ilike, relations, } from 'drizzle-orm';
export type { BunSQLDatabase, BunSQLPreparedQuery, BunSQLSession, BunSQLTransaction, } from 'drizzle-orm/bun-sql';
export { pgTable, pgSchema, pgEnum, pgView, bigint, bigserial, boolean, vector, char, cidr, customType, date, doublePrecision, inet, integer, interval, json, jsonb, macaddr, macaddr8, numeric, real, serial, smallint, smallserial, text, time, timestamp, uuid, varchar, primaryKey, foreignKey, unique, uniqueIndex, index, check, } from 'drizzle-orm/pg-core';
//# sourceMappingURL=index.d.ts.map